/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cassandra.clients;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;

import o.a.c.sidecar.client.shaded.io.vertx.core.net.OpenSSLEngineOptions;

import static org.assertj.core.api.Assertions.assertThat;

/**
 * Unit tests to ensure that Sidecar client native libraries are loaded correctly
 */
public class SidecarNativeLibrariesTest
{
    @DisplayName("Ensures that the shading is correct for the vertx-client-shaded project")
    @Test
    void openSslIsAvailable()
    {
        assertThat(OpenSSLEngineOptions.isAvailable()).isTrue();
    }
}
